==> haskell-abstract-par-0.3.3-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-abstract-par.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: abstract-par
version: 0.3.3
id: abstract-par-0.3.3-I2gvKCBAweu3uYwWNazPJ0
key: abstract-par-0.3.3-I2gvKCBAweu3uYwWNazPJ0
license: BSD3
copyright: (c) Ryan Newton 2011-2012
maintainer: Ryan Newton <rrnewton@gmail.com>
stability: Experimental
homepage: https://github.com/simonmar/monad-par
synopsis: Type classes generalizing the functionality of the '\''monad-par'\'' library.
description:
    The '\''Par'\'' monad offers a parallel programming API based on dataflow
    programming.  To use the `Par` monad, install the @monad-par@
    package, which includes this package as a dependency.
    .
    This package is an abstract interface only. It provides a number of
    type clasess, but not an implementation.  The type classes separate
    different levels of @Par@ functionality.  See the
    "Control.Monad.Par.Class" module for more details.
category: Control,Parallelism,Monads
author: Ryan Newton
exposed: True
exposed-modules:
    Control.Monad.Par.Class Control.Monad.Par.Unsafe
abi: 3ef7b538f83648561c8f46f743018003
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/abstract-par-0.3.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/abstract-par-0.3.3
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/abstract-par-0.3.3
hs-libraries: HSabstract-par-0.3.3-I2gvKCBAweu3uYwWNazPJ0
depends:
    base-4.9.0.0 deepseq-1.4.2.0
haddock-interfaces: /usr/share/doc/haskell-abstract-par/html/abstract-par.haddock
haddock-html: /usr/share/doc/haskell-abstract-par/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-abstract-par-0.3.3-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-abstract-par.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: abstract-par
version: 0.3.3
id: abstract-par-0.3.3-FIXQeoD8JqS8Il9xkWRf07
key: abstract-par-0.3.3-FIXQeoD8JqS8Il9xkWRf07
license: BSD3
copyright: (c) Ryan Newton 2011-2012
maintainer: Ryan Newton <rrnewton@gmail.com>
stability: Experimental
homepage: https://github.com/simonmar/monad-par
synopsis: Type classes generalizing the functionality of the '\''monad-par'\'' library.
description:
    The '\''Par'\'' monad offers a parallel programming API based on dataflow
    programming.  To use the `Par` monad, install the @monad-par@
    package, which includes this package as a dependency.
    .
    This package is an abstract interface only. It provides a number of
    type clasess, but not an implementation.  The type classes separate
    different levels of @Par@ functionality.  See the
    "Control.Monad.Par.Class" module for more details.
category: Control,Parallelism,Monads
author: Ryan Newton
exposed: True
exposed-modules:
    Control.Monad.Par.Class Control.Monad.Par.Unsafe
abi: 68c80924691222a015ee1a1c002fb509
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/abstract-par-0.3.3
library-dirs: /usr/lib/ghc-8.0.2/site-local/abstract-par-0.3.3
dynamic-library-dirs: /usr/lib/x86_64-linux-ghc-8.0.2
data-dir: /usr/share/x86_64-linux-ghc-8.0.2/abstract-par-0.3.3
hs-libraries: HSabstract-par-0.3.3-FIXQeoD8JqS8Il9xkWRf07
depends:
    base-4.9.1.0 deepseq-1.4.2.0
haddock-interfaces: /usr/share/doc/haskell-abstract-par/html/abstract-par.haddock
haddock-html: /usr/share/doc/haskell-abstract-par/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
